package
Version:
v0.0.0-...-2b5863b
Opens a new window with list of versions in this module.
Published: Jul 30, 2026
License: MIT
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
New builds the Cago framework analyzer.
type Settings struct {
APIDir string `json:"api-dir"`
ControllerDir string `json:"controller-dir"`
ServiceDir string `json:"service-dir"`
RepositoryDir string `json:"repository-dir"`
EntityDir string `json:"entity-dir"`
}
Settings configures Cago project conventions.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.